Bucket

Struct Bucket 

pub struct Bucket { /* private fields */ }

Implementations

Source

impl Bucket

pub fn new(max_nodes: usize, start_id: Id, end_id: Id) -> Self

pub fn add_node(&mut self, node: &Node) -> Result<(), BucketError>

Add a new ndoe, can fail if the bucket is full, if the node should not be inside this bucket and if the node is Local but there already is a local node in this bucket.

pub fn rm_node(&mut self, id: Id)

Remove a node by its ID

pub fn local(&self) -> Result<Node, BucketError>

Check if the bucket contains the node that represents us

pub fn divide(&mut self) -> Option<Self>

Divide bucket and split the ID space between the two. It also moves the nodes to the new bucket if necessary.

pub fn get(&self, i: usize) -> Result<Node, BucketError>

Get a node from the bucket by its index, can fail if index is incorrect.

pub fn get_by_id(&self, id: &Id) -> Result<Node, BucketError>

Get a node from the bucket by its ID.

pub fn fits(&self, id: &Id) -> bool

Check if a node fits inside the bucket (in terms of ID)

pub fn nodes(&self) -> &Vec<Node>

Get list of nodes inside a bucket